var group___cg_program_manager =
[
    [ "CgFxScriptLoader", "class_ogre_1_1_cg_fx_script_loader.html", [
      [ "CgFxScriptLoader", "class_ogre_1_1_cg_fx_script_loader.html#ad49475d8c23dc210475cd8d65ace72a4", null ],
      [ "~CgFxScriptLoader", "class_ogre_1_1_cg_fx_script_loader.html#a3670a8d9b0c6b3f3f5bc125624ded6c5", null ],
      [ "getScriptPatterns", "class_ogre_1_1_cg_fx_script_loader.html#af6a6df38b68d59f327ba875b45c6780e", null ],
      [ "parseScript", "class_ogre_1_1_cg_fx_script_loader.html#a8cc3006cecef12aceeeefa7733ebc541", null ],
      [ "getLoadingOrder", "class_ogre_1_1_cg_fx_script_loader.html#a48bcf80ad0eabe9317777920b5d8d1a2", null ],
      [ "getSingleton", "class_ogre_1_1_cg_fx_script_loader.html#ad21a320aa22feb20ac3685e064973cf4", null ],
      [ "getSingletonPtr", "class_ogre_1_1_cg_fx_script_loader.html#a930f43b6d3493e5a7183e1422874d085", null ]
    ] ],
    [ "CgProgram", "class_ogre_1_1_cg_program.html", [
      [ "CmdArgs", "class_ogre_1_1_cg_program_1_1_cmd_args.html", [
        [ "doGet", "class_ogre_1_1_cg_program_1_1_cmd_args.html#a9ad1f0e009c56553ff19116413999b01", null ],
        [ "doSet", "class_ogre_1_1_cg_program_1_1_cmd_args.html#a4d20dfa73d5b6f13c078999b79271c4e", null ]
      ] ],
      [ "CmdEntryPoint", "class_ogre_1_1_cg_program_1_1_cmd_entry_point.html", [
        [ "doGet", "class_ogre_1_1_cg_program_1_1_cmd_entry_point.html#a79d93e9bea52a708a27368b0508831bb", null ],
        [ "doSet", "class_ogre_1_1_cg_program_1_1_cmd_entry_point.html#a0189d59b6e17534917433f51521cfc96", null ]
      ] ],
      [ "CmdProfiles", "class_ogre_1_1_cg_program_1_1_cmd_profiles.html", [
        [ "doGet", "class_ogre_1_1_cg_program_1_1_cmd_profiles.html#a542db52fe7cca161787ed98be01e644b", null ],
        [ "doSet", "class_ogre_1_1_cg_program_1_1_cmd_profiles.html#acf5d995eeaf0b92442dd0a1ca847a054", null ]
      ] ],
      [ "LoadingState", "class_ogre_1_1_cg_program.html#a07e619aa09d3bc6789a6667cb4fc572c", [
        [ "LOADSTATE_UNLOADED", "class_ogre_1_1_cg_program.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94", null ],
        [ "LOADSTATE_LOADING", "class_ogre_1_1_cg_program.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5", null ],
        [ "LOADSTATE_LOADED", "class_ogre_1_1_cg_program.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f", null ],
        [ "LOADSTATE_UNLOADING", "class_ogre_1_1_cg_program.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e", null ],
        [ "LOADSTATE_PREPARED", "class_ogre_1_1_cg_program.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1", null ],
        [ "LOADSTATE_PREPARING", "class_ogre_1_1_cg_program.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb", null ]
      ] ],
      [ "LoadingFlags", "class_ogre_1_1_cg_program.html#a1aa750a4b994f2b1066220936cdfdb94", [
        [ "LF_DEFAULT", "class_ogre_1_1_cg_program.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c", null ],
        [ "LF_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_cg_program.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809", null ],
        [ "LF_ONLY_UNREFERENCED", "class_ogre_1_1_cg_program.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782", null ],
        [ "LF_ONLY_UNREFERENCED_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_cg_program.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77", null ],
        [ "LF_PRESERVE_STATE", "class_ogre_1_1_cg_program.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c", null ]
      ] ],
      [ "CgProgram", "class_ogre_1_1_cg_program.html#a1c9bcda5777d1915f573077b2d50d43a", null ],
      [ "~CgProgram", "class_ogre_1_1_cg_program.html#a65a32235ed550af62066095e5e7735b5", null ],
      [ "setEntryPoint", "class_ogre_1_1_cg_program.html#a0ba32899c330445ac2984d97adb2e142", null ],
      [ "getEntryPoint", "class_ogre_1_1_cg_program.html#aef3513510b1e8d34dc95f28b589e7b02", null ],
      [ "setProfiles", "class_ogre_1_1_cg_program.html#a07ccc5d1e5e5ff900a696986e4729cd9", null ],
      [ "getProfiles", "class_ogre_1_1_cg_program.html#acd74bfad569b567e99cfe44cb2bb99ad", null ],
      [ "isSupported", "class_ogre_1_1_cg_program.html#ae4968f949a99e5e10f82bfc904479bd5", null ],
      [ "getLanguage", "class_ogre_1_1_cg_program.html#a5b9074b10dd674d98666fee888cd6bb3", null ],
      [ "createParameters", "class_ogre_1_1_cg_program.html#a9461e01449c3773e502cb5071bbca2ae", null ],
      [ "_getBindingDelegate", "class_ogre_1_1_cg_program.html#aaaf0cd27fd6604cc644e66f101844f08", null ],
      [ "isSkeletalAnimationIncluded", "class_ogre_1_1_cg_program.html#a86dfdb6d47afc2196ceaae0751942883", null ],
      [ "isMorphAnimationIncluded", "class_ogre_1_1_cg_program.html#a38cba04e83702fbf98c4fb3cc5e1538d", null ],
      [ "isPoseAnimationIncluded", "class_ogre_1_1_cg_program.html#aeaa52d1e75245cee8186841eb983a0da", null ],
      [ "isVertexTextureFetchRequired", "class_ogre_1_1_cg_program.html#a9bb5c2cd8a2d4e76794c7596d0c9d57e", null ],
      [ "getDefaultParameters", "class_ogre_1_1_cg_program.html#a1f21af4659df48a155db980bdadbf5f1", null ],
      [ "hasDefaultParameters", "class_ogre_1_1_cg_program.html#a94fbe95dc398989b4de6d981a17fbc6d", null ],
      [ "getPassSurfaceAndLightStates", "class_ogre_1_1_cg_program.html#a9584e7691cce3a52b8d26e4540359892", null ],
      [ "getPassFogStates", "class_ogre_1_1_cg_program.html#a2822db9a2976b9a5470adde82073cbf5", null ],
      [ "getPassTransformStates", "class_ogre_1_1_cg_program.html#ae376230400171f70c3270f67f476b1bf", null ],
      [ "hasCompileError", "class_ogre_1_1_cg_program.html#a8fe80144b24cde184f0a07f6f3f290d1", null ],
      [ "resetCompileError", "class_ogre_1_1_cg_program.html#a7ce0be99072f2ffd6055cd3bbd20b625", null ],
      [ "getSize", "class_ogre_1_1_cg_program.html#a65a86c6f911a8ac4b0c6d7366fb44f26", null ],
      [ "touch", "class_ogre_1_1_cg_program.html#aa448e3603f9f6cad8cfe40818888227a", null ],
      [ "getConstantDefinitions", "class_ogre_1_1_cg_program.html#ac281d547b47b872fe35e1e60fe07612a", null ],
      [ "calculateSize", "class_ogre_1_1_cg_program.html#a62ecd906ba236975ddec42c62d0b4e2b", null ],
      [ "setPreprocessorDefines", "class_ogre_1_1_cg_program.html#abf8f87f03e2d3b147b7f28c76c1307a7", null ],
      [ "getPreprocessorDefines", "class_ogre_1_1_cg_program.html#ad37956c9bababb03b8ce7aaf13d0f39b", null ],
      [ "_resolveIncludes", "class_ogre_1_1_cg_program.html#a827096909b3c5ef1ff46b880e1606b76", null ],
      [ "getProgramTypeName", "class_ogre_1_1_cg_program.html#a74fe58cd0a7dcfcc55902fc3d9890b82", null ],
      [ "setSourceFile", "class_ogre_1_1_cg_program.html#a8d265ebc2472f77cf9675dec005a123a", null ],
      [ "setSource", "class_ogre_1_1_cg_program.html#af0194bcb85a757f23cd8681c4611a4fb", null ],
      [ "getSyntaxCode", "class_ogre_1_1_cg_program.html#a7b7db741c7eab2838fd53149c41357e5", null ],
      [ "setSyntaxCode", "class_ogre_1_1_cg_program.html#ac7b2745e88eabb52b640a77f03e0f896", null ],
      [ "getSourceFile", "class_ogre_1_1_cg_program.html#a0ff78514ce645dd55ad1bb27c84a5b29", null ],
      [ "getSource", "class_ogre_1_1_cg_program.html#a1d7c13588f43121426317475910d31d5", null ],
      [ "setType", "class_ogre_1_1_cg_program.html#af2b6c0ff81145fa460079c716e0ba84e", null ],
      [ "getType", "class_ogre_1_1_cg_program.html#a326c46942f2b3f707ab130442c880273", null ],
      [ "setSkeletalAnimationIncluded", "class_ogre_1_1_cg_program.html#af337509a5342cb707df4df78337756ae", null ],
      [ "setMorphAnimationIncluded", "class_ogre_1_1_cg_program.html#a843c706f65d219c1d04b8aeacc4bd3c8", null ],
      [ "setPoseAnimationIncluded", "class_ogre_1_1_cg_program.html#a848bf4164963cf8c0435c972eb717e0f", null ],
      [ "getNumberOfPosesIncluded", "class_ogre_1_1_cg_program.html#af0be69f3df55f71c0bded2e36c89dfa6", null ],
      [ "setVertexTextureFetchRequired", "class_ogre_1_1_cg_program.html#a463bffd1f68fc8ae3c29d64402e9ca8d", null ],
      [ "setAdjacencyInfoRequired", "class_ogre_1_1_cg_program.html#a39b43157d6b40626101e5de8f9c77bf5", null ],
      [ "isAdjacencyInfoRequired", "class_ogre_1_1_cg_program.html#a6e4126e3d4bdc85eb3bfb4530c8e8249", null ],
      [ "setComputeGroupDimensions", "class_ogre_1_1_cg_program.html#a84c3904bfaeeb1166dbca41e0c9f3b29", null ],
      [ "getComputeGroupDimensions", "class_ogre_1_1_cg_program.html#a39e694fafadbf623d7e865bc30b3362b", null ],
      [ "setManualNamedConstants", "class_ogre_1_1_cg_program.html#a25757132c8ee96c8e7ffef209ddfb078", null ],
      [ "setManualNamedConstantsFile", "class_ogre_1_1_cg_program.html#af420c447afb13728b4ddfcb8d8d7d812", null ],
      [ "getManualNamedConstantsFile", "class_ogre_1_1_cg_program.html#ae0630743f8c509bc341d294ebfc433f4", null ],
      [ "_getHash", "class_ogre_1_1_cg_program.html#a38f6c696b57b698b6c778820a341c27b", null ],
      [ "prepare", "class_ogre_1_1_cg_program.html#a350b287fa3e83a389221274f68760008", null ],
      [ "load", "class_ogre_1_1_cg_program.html#a699d1c851f494a8d5d23d23b695ceb47", null ],
      [ "reload", "class_ogre_1_1_cg_program.html#a5016aec1762b026997ddd346775879ef", null ],
      [ "isReloadable", "class_ogre_1_1_cg_program.html#a8eb34a9034aab62fd537c021a79e3366", null ],
      [ "isManuallyLoaded", "class_ogre_1_1_cg_program.html#a8f541900f7e1f73f4c313a732199029a", null ],
      [ "unload", "class_ogre_1_1_cg_program.html#aa31bef1bfaa87731622e56f11b548e27", null ],
      [ "getName", "class_ogre_1_1_cg_program.html#a0646fba8aa0242c6b389d73f47ebe41b", null ],
      [ "getHandle", "class_ogre_1_1_cg_program.html#a2298551707debaf774d577e643ee856a", null ],
      [ "isPrepared", "class_ogre_1_1_cg_program.html#a0779c46df96234b6619a5f57fbb36078", null ],
      [ "isLoaded", "class_ogre_1_1_cg_program.html#a74138c0203835513613af73cdb08890d", null ],
      [ "isLoading", "class_ogre_1_1_cg_program.html#a3af26f716731b64850ea50cfa4d2edef", null ],
      [ "getLoadingState", "class_ogre_1_1_cg_program.html#a1e90ade99935ef70ec5b199243bf995b", null ],
      [ "isBackgroundLoaded", "class_ogre_1_1_cg_program.html#a60ce96525ac730a0f7b466ed287beef3", null ],
      [ "setBackgroundLoaded", "class_ogre_1_1_cg_program.html#ae0a0007de944eb3c2f933a372a752b35", null ],
      [ "escalateLoading", "class_ogre_1_1_cg_program.html#a367f6fe60bb211cb4c32e3825ca67e4c", null ],
      [ "addListener", "class_ogre_1_1_cg_program.html#a5513ffce404b14cff72846318b018d32", null ],
      [ "removeListener", "class_ogre_1_1_cg_program.html#a3c49142f739ba8fb56d6e7b3db235fb7", null ],
      [ "getGroup", "class_ogre_1_1_cg_program.html#a382919945c07a6a13136889ad3fbf578", null ],
      [ "changeGroupOwnership", "class_ogre_1_1_cg_program.html#aa5d6f3f7e73b77b233fc62b11f270e4d", null ],
      [ "getCreator", "class_ogre_1_1_cg_program.html#ab6e377a3964d566ea112fe63bf1d7678", null ],
      [ "getOrigin", "class_ogre_1_1_cg_program.html#a13423fa7944d7f2339e78b9de026c3be", null ],
      [ "_notifyOrigin", "class_ogre_1_1_cg_program.html#a7e248a1cca0662418d4ab3f63c2e7cf6", null ],
      [ "getStateCount", "class_ogre_1_1_cg_program.html#ade85e4d5579519e4117a84789c0ae8fd", null ],
      [ "_dirtyState", "class_ogre_1_1_cg_program.html#afcb4a61b965600a67ca2c2f060821db9", null ],
      [ "_fireLoadingComplete", "class_ogre_1_1_cg_program.html#aa68664db6b8723dc198beef3d21d4ef5", null ],
      [ "_firePreparingComplete", "class_ogre_1_1_cg_program.html#aaf63d096584ac7d97fe1d1b0226c9561", null ],
      [ "_fireUnloadingComplete", "class_ogre_1_1_cg_program.html#aaf3746937cd11864f53bc1c3b4437541", null ],
      [ "getParamDictionary", "class_ogre_1_1_cg_program.html#ae3e13925bde11db245f6c9bbf5031a93", null ],
      [ "getParamDictionary", "class_ogre_1_1_cg_program.html#a0f55da0550a7e1ab70a1c8bf598a3e20", null ],
      [ "getParameters", "class_ogre_1_1_cg_program.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d", null ],
      [ "setParameter", "class_ogre_1_1_cg_program.html#a08d117bf25f011f96d81f1f4ecb25113", null ],
      [ "setParameterList", "class_ogre_1_1_cg_program.html#a9aac32f93bd149a34b809a57a9f01f8f", null ],
      [ "getParameter", "class_ogre_1_1_cg_program.html#a1d078304c38a9f85d483fc8ed0cdf1fe", null ],
      [ "copyParametersTo", "class_ogre_1_1_cg_program.html#aad68d8b18faad14e8286a67527094654", null ],
      [ "cleanupDictionary", "class_ogre_1_1_cg_program.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8", null ],
      [ "OGRE_AUTO_MUTEX", "class_ogre_1_1_cg_program.html#a104d9db8bfcff1f37b29157bbe070f7a", null ]
    ] ],
    [ "CgProgramFactory", "class_ogre_1_1_cg_program_factory.html", [
      [ "CgProgramFactory", "class_ogre_1_1_cg_program_factory.html#a86752f3ed3d01ad2fbc665ee3ba70a96", null ],
      [ "~CgProgramFactory", "class_ogre_1_1_cg_program_factory.html#a3d50a30e2f42740c090480143f55a5fa", null ],
      [ "getLanguage", "class_ogre_1_1_cg_program_factory.html#abf5b3712c5577401d085544a045ce549", null ],
      [ "create", "class_ogre_1_1_cg_program_factory.html#ab4e67b062cc70d29df7e7d169bb88e71", null ],
      [ "destroy", "class_ogre_1_1_cg_program_factory.html#a981698847d227ebfdc30a1ed3cc1dd61", null ]
    ] ]
];